@@ -50,8 +50,7 @@ NetworkPlugin::NetworkPlugin(QObject *parent, const QVariantList &args)
 
     connect(m_process, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), [=](int exitCode, QProcess::ExitStatus status) {
         if (exitCode != 0 || status != QProcess::NormalExit) {
-            qCWarning(KSYSGUARD_PLUGIN_NETWORK) << "Helper process terminated abnormally!";
-            qCWarning(KSYSGUARD_PLUGIN_NETWORK) << m_process->readAllStandardError();
+            qCWarning(KSYSGUARD_PLUGIN_NETWORK) << "Helper process terminated abnormally:" << m_process->readAllStandardError().trimmed();
         }
     });
 
@@ -60,7 +59,11 @@ NetworkPlugin::NetworkPlugin(QObject *parent, const QVariantList &args)
             const QString line = QString::fromUtf8(m_process->readLine());
 
             // Each line consists of: timestamp|PID|pid|IN|in_bytes|OUT|out_bytes
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             const auto parts = line.splitRef(QLatin1Char('|'), Qt::SkipEmptyParts);
+#else
+            const auto parts = QStringView(line).split(QLatin1Char('|'), Qt::SkipEmptyParts);
+#endif
             if (parts.size() < 7) {
                 continue;
             }
